Description Usage Arguments Value Examples
View source: R/helpers-landing.R
Make Description Text
1 | make_description(rawHTML = FALSE, ...)
|
rawHTML |
Logical: FALSE by default. If TRUE, raw HTML string should be supplied. FALSE and shiny functions should be utilized to create text. |
... |
Character string of HTML or shiny functions |
HTML for description text in landing page.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 | if (interactive()) {
# To use {shiny} functions
make_description(rawHTML = FALSE,
tagList(
column(3, p( "You have been selected to participate in a task that does...")),
column(3, p("This task will take approximately ... it is optional..."))
)
)
# To use HTML
make_description(rawHTML = TRUE,
'
<div class = "col-sm-3 box mx-4 p-4 text-center">
You have been selected to participate in a task that does...
</div>
<div class = "col-sm-3 box mx-4 p-4 text-center">
<center>
<p>This task will take approximately ... it is optional...</p>
</center>
</div>
<div class = "col-sm-3 box mx-4 p-4 text-center">
<center>
<p>You will be compensated ... </p>
</center>
</div>
')
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.